==> rockverse-1.0.0.tar.gz: rockverse-1.0.0/README.md <==
<img src="https://github.com/rodolfovictor/rockverse/blob/main/docs/source/_static/RockVerse_logo_model3_for_white_background_facecolor_transparent_False.png"><br>


RockVerse: Python tools for Computational Petrophysics
======================================================

RockVerse is an open-source Python library designed to support high-performance
computational petrophysics workflows. It is optimized for large-scale simulations
and memory-intensive data processing. Leveraging state-of-the-art tools, the
library delivers optimized performance across CPU and GPU parallel computing
environments.

This project is under ongoing development as part of a post-doctoral research
initiative, and we welcome contributions, bug reports, and feature suggestions.

Documentation
-------------

Online documentation is available at [rockverse.readthedocs.io](https://rockverse.readthedocs.io),
featuring API reference, tutorials and sample gallery.

Installation
------------

Follow our online [installation guide](https://rockverse.readthedocs.io/en/latest/getting_started/install.html)
to get started.

Development
-----------

RockVerse is open and hosted at Github: https://github.com/rodolfovictor/rockverse

Fell free to submit bugs to the [issue tracker](https://github.com/rodolfovictor/rockverse/issues).
Please remember to include the RockVerse version and a reproducible example demonstrating the problem.

Questions
---------

For general questions consider using StackOverflow with a [rockverse tag](https://stackoverflow.com/tags/rockverse).

==> rockverse-1.1.0.tar.gz: rockverse-1.1.0/README.md <==
<img src="https://raw.githubusercontent.com/rodolfovictor/rockverse/main/docs/source/_static/RockVerse_logo_model3_for_white_background_facecolor_transparent_False.png"><br>

RockVerse: Python tools for Computational Petrophysics
======================================================

[![PyPI Version](https://img.shields.io/pypi/v/rockverse.svg)](https://pypi.org/project/rockverse/)
[![License](https://img.shields.io/pypi/l/rockverse.svg)](https://github.com/rodolfovictor/rockverse/blob/main/LICENSE.md)
[![Anaconda](https://anaconda.org/conda-forge/rockverse/badges/version.svg)](https://anaconda.org/conda-forge/rockverse)


RockVerse is an open-source Python library designed to support high-performance
computational petrophysics workflows. It is optimized for large-scale simulations
and memory-intensive data processing. Leveraging state-of-the-art tools, the
library delivers optimized performance across CPU and GPU parallel computing
environments.

This project is under ongoing development as part of a post-doctoral research
initiative, and we welcome contributions, bug reports, and feature suggestions.

Documentation
-------------

Online documentation is available at [rockverse.readthedocs.io](https://rockverse.readthedocs.io),
featuring API reference, tutorials and sample gallery.

Installation
------------

Follow our online [installation guide](https://rockverse.readthedocs.io/en/latest/install.html)
to get started.

Development
-----------

RockVerse is open and hosted at Github: https://github.com/rodolfovictor/rockverse

Fell free to submit bugs to the [issue tracker](https://github.com/rodolfovictor/rockverse/issues).
Please remember to include the RockVerse version and a reproducible example demonstrating the problem.

Questions
---------

For general questions consider using StackOverflow with a [rockverse tag](https://stackoverflow.com/tags/rockverse).
